@@ -9,16 +9,14 @@
 
 if type alr; then
     echo "building gpr-mode executables via Alire"
-    alr get emacs_gpr_mode
+    alr get emacs_gpr_mode~1.0.1
+    cd emacs_gpr_mode_*; alr build --release
 
 elif type gprbuild; then
     echo "building gpr-mode executables via gnat compiler"
     
-    if [ -d ../wisi-4.1.? ]; then
-        WISI_DIR=`ls -d ../wisi-4.0.?`
-    else
-        # try devel version
-        WISI_DIR=`find .. -type d -name "wisi-4.0beta*"`
+    if [ -d ../wisi-4.2.? ]; then
+        WISI_DIR=`ls -d ../wisi-4.2.?`
     fi
 
     args=`echo -DELPA="yes" $WISI_DIR/wisi.gpr.gp $WISI_DIR/wisi.gpr`
